/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EntityIdGenerator;
import nl.cloudfarming.client.stock.crop.visual.nodes.ClassificationAggregateNode;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Add a new Classification to the active crop in the croplist.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({
    "Add classification action name=Add classification",
    "Add classification action tooltip=Add classification",
    "Classification default name=User created classification"
})
public class AddClassificationAction extends AbstractAction {

    private static final String ADD_CLASSIFICATION_ACTION_TOOLTIP = Bundle.Add_classification_action_tooltip();
    private static final String ADD_CLASSIFICATION_ICON = "nl/cloudfarming/client/stock/crop/classification.png";
    private static final String ADD_CLASSIFICATION_ENABLED = "nl/cloudfarming/client/stock/crop/classification.png";
    private static final String ADD_CLASSIFICATION_DISABLED = "nl/cloudfarming/client/stock/crop/classification.png";
    private Lookup context;

    /**
     * Makes this action for a specific node
     */
    public AddClassificationAction(Lookup context) {
        super(Bundle.Add_classification_action_name());
        this.context = context;
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CLASSIFICATION_ICON));
        this.putValue(Action.SHORT_DESCRIPTION, ADD_CLASSIFICATION_ACTION_TOOLTIP);
    }

    @Override
    public void setEnabled(boolean doEnable) {
        if (doEnable) {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CLASSIFICATION_ENABLED));
        } else {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CLASSIFICATION_DISABLED));
        }
        super.setEnabled(doEnable);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // Find active crop
        ClassificationAggregateNode node = context.lookup(ClassificationAggregateNode.class);
        CropDefinition activeCropDefinition = node.getParentNode().getLookup().lookup(CropDefinition.class);
        assert activeCropDefinition != null : "Tried to add classification, but parent cropdefinition cannot be found in lookup";

        String source = Bundle.Crop_default_source();
        String name = Bundle.Classification_default_name();
        EntityIdGenerator idGenerator = Lookup.getDefault().lookup(EntityIdGenerator.class);
        String id = source + "/" + idGenerator.generateId(EntityIdGenerator.USER_DEFINED_KEY);
        // Create new classification for the active crop
        Classification classification = new Classification(new AgroURI("OTHER/00000000/CLN/0"), source, name);
        activeCropDefinition.addClassification(classification);

        // determine if ClassificationNode is expanded or not
        // if not expanded: expand it


    }
}
