/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Crop;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import nl.cloudfarming.client.stock.crop.storage.CropDefinitionStorage;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * Add a new empty cropdefinition to the croplist.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({
    "Add crop action name=Add crop",
    "Crop default source=User created",
    "Crop default name=User created cropdef",
    "Add crop action tooltip=Add crop"
})
public class AddCropDefinitionAction extends AbstractAction {

    private static final String ADD_CROPDEFINITION_ACTION_TOOLTIP = Bundle.Add_crop_action_tooltip();
    private static final String ADD_CROPDEFINITION_ICON = "nl/cloudfarming/client/stock/crop/addcropdefinition.png";

    /**
     * Makes this action for a specific node
     *
     * @param cropDefinitionNode
     */
    public AddCropDefinitionAction() {
        super(Bundle.Add_crop_action_name());
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_CROPDEFINITION_ICON));
        this.putValue(Action.SHORT_DESCRIPTION, ADD_CROPDEFINITION_ACTION_TOOLTIP);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        String source = Bundle.Crop_default_source();
        String name = Bundle.Crop_default_name();

        EnterpriseIdProvider eip = new AgroURI("AGRONL/00000000/CRP/0");
        Crop crop = new Crop(eip, name);
        
        CropDefinition cropDefinition = new CropDefinition(eip, crop);
        cropDefinition.setSource(source);
        CropDefinitionStorage.getInstance().addCropDefinition(cropDefinition);
    }
}
