/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Variety;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EntityIdGenerator;
import nl.cloudfarming.client.stock.crop.visual.nodes.VarietyAggregateNode;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Add a new Variety to the active crop in the croplist.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({
    "Add variety action name=Add variety",
    "Add variety action tooltip=Add variety",
    "Variety default name=User created variety",
    "Variety default color=Default color",})
public class AddVarietyAction extends AbstractAction {

    private static final String ADD_VARIETY_ACTION_TOOLTIP = Bundle.Add_variety_action_tooltip();
    private static final String ADD_VARIETY_ICON = "nl/cloudfarming/client/stock/crop/variety.png";
    private static final String ADD_VARIETY_ENABLED = "nl/cloudfarming/client/stock/crop/variety.png";
    private static final String ADD_VARIETY_DISABLED = "nl/cloudfarming/client/stock/crop/variety.png";
    private Lookup context;

    /**
     * Makes this action for a specific node
     *
     * @param cropDefinitionNode
     */
    public AddVarietyAction(Lookup context) {
        super(Bundle.Add_variety_action_name());
        this.context = context;
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_VARIETY_ICON));
        this.putValue(Action.SHORT_DESCRIPTION, ADD_VARIETY_ACTION_TOOLTIP);
    }

    @Override
    public void setEnabled(boolean doEnable) {
        if (doEnable) {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_VARIETY_ENABLED));
        } else {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_VARIETY_DISABLED));
        }
        super.setEnabled(doEnable);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // Find active crop
        VarietyAggregateNode node = context.lookup(VarietyAggregateNode.class);
        CropDefinition activeCropDefinition = node.getParentNode().getLookup().lookup(CropDefinition.class);
        assert activeCropDefinition != null : "Tried to add variety, but parent cropdefinition cannot be found in lookup";

        String source = Bundle.Crop_default_source();
        String name = Bundle.Variety_default_name();
        EntityIdGenerator idGenerator = Lookup.getDefault().lookup(EntityIdGenerator.class);
        String id = source + "/" + idGenerator.generateId(EntityIdGenerator.USER_DEFINED_KEY);
        // Create new variety for the active crop
        Variety variety = new Variety(new AgroURI("OTHER/00000000/VTY/0"), source, name);
        activeCropDefinition.addVariety(variety);
    }
}
