/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.actions;

import java.awt.event.ActionEvent;
import java.util.Collection;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Variety;
import nl.cloudfarming.client.stock.crop.storage.CropDefinitionStorage;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Removes selected items in the croplist. Supports Crops, classifications and
 * varieties For classifications and varieties the parent cropdefinition must
 * also be in the lookup.
 *
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages("Remove_action_name=Remove")
public class RemoveAction extends AbstractAction {

    private static final String REMOVE_ACTION_TOOLTIP = "Remove";//Bundle.toolbar_remove_action_tooltip();
    private String REMOVE_ICON_ENABLED = "nl/cloudfarming/client/stock/crop/enabled_cross.png";
    private String REMOVE_ICON_DISABLED = "nl/cloudfarming/client/stock/crop/disabled_cross.png";
    private Lookup context;

    public RemoveAction(Lookup context) {
        super(Bundle.Remove_action_name());

        this.context = context;
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_DISABLED));
        this.putValue(Action.SHORT_DESCRIPTION, REMOVE_ACTION_TOOLTIP);
    }

    @Override
    public void setEnabled(boolean doEnable) {
        if (doEnable) {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_ENABLED));
        } else {
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_DISABLED));
        }
        super.setEnabled(doEnable);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        for (CropDefinition cropDefinition : getSelectedCropDefinitions()) {
            removeSelectedClassifications(cropDefinition);
            removeSelectedVarieties(cropDefinition);
            removeSelectedCropDefinition(cropDefinition);
        }
    }

    private Collection<? extends CropDefinition> getSelectedCropDefinitions() {
        return context.lookupAll(CropDefinition.class);
    }

    private void removeSelectedClassifications(CropDefinition cropDefinition) {
        for (Classification classification : getSelectedClassifications()) {
            cropDefinition.removeClassification(classification);
        }
    }

    private Collection<? extends Classification> getSelectedClassifications() {
        return context.lookupAll(Classification.class);
    }
    
    private void removeSelectedVarieties(CropDefinition cropDefinition) {
        for (Variety variety : getSelectedVarieties()) {
            cropDefinition.removeVariety(variety);
        }
    }

    private Collection<? extends Variety> getSelectedVarieties() {
        return context.lookupAll(Variety.class);
    }
    
    private void removeSelectedCropDefinition(CropDefinition cropDefinition) {
        if(getSelectedClassifications().isEmpty() && getSelectedVarieties().isEmpty()) {
            CropDefinitionStorage.getInstance().removeCropDefinition(cropDefinition);
        }
    }
}
