/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.visual.nodes;

import java.beans.IntrospectionException;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.stock.crop.actions.AddClassificationAction;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;


/**
 * Aggregate node under a cropdefinitionnode to group classifications of this cropdefinitionnode together
 * @author Gerben Feenstra
 */
@NbBundle.Messages("ClassificationNode.name=Classifications")
public class ClassificationAggregateNode extends AbstractNode {
    
    private static final String CLASSIFICATION_AGGREGATE_ICON = "nl/cloudfarming/client/stock/crop/classification_aggregate.png";
        
    public ClassificationAggregateNode(CropDefinition cropDefinition, Lookup lookup) {
        super(Children.create(new ClassificationChildFactory(cropDefinition, lookup), true));
        setName(Bundle.ClassificationNode_name());
        this.setIconBaseWithExtension(CLASSIFICATION_AGGREGATE_ICON);
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.stock.crop.classification");
    }
    
    @Override
    public Action[] getActions(boolean context) {
        Action[] actions = new Action[1];
        actions[0] = new AddClassificationAction(getLookup());
        return actions;
    }
}
/**
 * Create individual classification nodes 
 * @author Gerben Feenstra
 */
class ClassificationChildFactory extends ChildFactory<Classification> implements PropertyChangeListener {

    private Lookup lookup;
    CropDefinition cropDefinition;

    public ClassificationChildFactory(CropDefinition cropDefinition, Lookup lookup) {
        this.cropDefinition = cropDefinition;
        this.lookup = lookup;
        cropDefinition.addPropertyChangeListener(CropDefinition.PROP_CLASSIFICATIONS, this);
    }

    @Override
    protected boolean createKeys(List<Classification> toPopulate) {
        toPopulate.addAll(this.cropDefinition.getClassifications());
        return true;
    }

    @Override
    protected Node createNodeForKey(Classification key) {
        try {
            return new ClassificationNode(key, lookup);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        this.refresh(true);
    }
}