/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop.visual.nodes;

import java.beans.IntrospectionException;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.*;
import nl.cloudfarming.client.stock.crop.actions.RemoveAction;
import org.openide.nodes.BeanNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.lookup.Lookups;

/**
 * Node which represents a cropdefinition.
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class CropDefinitionNode extends BeanNode<CropDefinition> {

    private CropDefinition cropDefinition;
    private static final String CROPDEFINITION_ICON = "nl/cloudfarming/client/stock/crop/cropdefinition.png";

    /**
     * Construct node from cropdefinition, puts cropdefinition in its lookup.
     *
     * @param cropDefinition
     * @throws IntrospectionException
     */
    public CropDefinitionNode(CropDefinition cropDefinition) throws IntrospectionException {
        super(cropDefinition, new CropDefinitionChildren(cropDefinition), Lookups.fixed(cropDefinition));
        this.cropDefinition = cropDefinition;
        this.setIconBaseWithExtension(CROPDEFINITION_ICON);
    }

    /**
     * Returns the actions that can be invoked on this cropDefinitionNode
     *
     * @param context Not used
     * @return Array of actions for this node
     */
    @Override
    public Action[] getActions(boolean context) {
        Action[] actions = new Action[1];
        actions[0] = new RemoveAction(getLookup());
        return actions;
    }

    @Override
    public Action getPreferredAction() {
        return null;
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.stock.crop.croplist");
    }

    /**
     * Returns the cropdefinition belonging to this node.
     *
     * @return The cropdefinition
     */
    public CropDefinition getCropDefinition() {
        return cropDefinition;
    }

    /**
     * Creates children (varieties and classifications) for a cropdefinition
     * node
     */
    private static class CropDefinitionChildren extends Children.Keys<CropDefinition> {

        public CropDefinitionChildren(CropDefinition bean) {
            setKeys(new CropDefinition[]{bean});
            addNotify();
        }

        @Override
        protected Node[] createNodes(CropDefinition cropDefinition) {
            Node classificationAggregateNode = new ClassificationAggregateNode(cropDefinition, Lookups.fixed(cropDefinition));
            Node varietyAggregateNode = new VarietyAggregateNode(cropDefinition, Lookups.fixed(cropDefinition));
            return new Node[]{classificationAggregateNode, varietyAggregateNode};
        }
    }
}
