/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.visual.nodes;

import java.beans.IntrospectionException;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.List;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.stock.crop.storage.CropDefinitionStorage;
import nl.cloudfarming.client.stock.crop.storage.PropertyChangeTracker;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 * Factory to create children for the (invisible) root Crops node. 
 * 
 * @author Gerben Feenstra
 */
public class CropsChildFactory extends ChildFactory<CropDefinition> implements PropertyChangeListener {

    private PropertyChangeTracker propertyChangeTracker;
    
    public CropsChildFactory(PropertyChangeTracker tracker) {
        this.propertyChangeTracker = tracker;
        CropDefinitionStorage.getInstance().addPropertyChangeListener(CropDefinitionStorage.PROP_CROP_DEFINITION_ADDREMOVE, this);
    }

    @Override
    protected boolean createKeys(List<CropDefinition> toPopulate) {
        toPopulate.addAll(CropDefinitionStorage.getInstance().getCropDefinitions());
        addPropertyChangeTracker(toPopulate);
        return true;
    }

    @Override
    protected Node createNodeForKey(CropDefinition key) {
        try {
            return new CropDefinitionNode(key);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        this.refresh(true);
    }
    
    private void addPropertyChangeTracker(List<CropDefinition> cropDefinitions) {
        for(CropDefinition cropDefinition : cropDefinitions) {
            cropDefinition.addPropertyChangeListener(propertyChangeTracker);
        }
    }
}