/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop.visual.nodes;

import java.beans.IntrospectionException;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Variety;
import nl.cloudfarming.client.stock.crop.actions.AddVarietyAction;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Aggregate node under a cropdefinitionnode to group varieties of this
 * cropdefinitionnode together
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages("VarietyNode.name=Varieties")
public class VarietyAggregateNode extends AbstractNode {

    private static final String VARIETY_AGGREGATE_ICON = "nl/cloudfarming/client/stock/crop/variety_aggregate.png";

    public VarietyAggregateNode(CropDefinition cropDefinition, Lookup lookup) {
        super(Children.create(new VarietyChildFactory(cropDefinition, lookup), true));
        setName(Bundle.VarietyNode_name());
        this.setIconBaseWithExtension(VARIETY_AGGREGATE_ICON);
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.stock.crop.variety");
    }

    @Override
    public Action[] getActions(boolean context) {
        Action[] actions = new Action[1];
        actions[0] = new AddVarietyAction(getLookup());
        return actions;
    }
}

/**
 * Create individual variety nodes
 *
 * @author Gerben Feenstra
 */
class VarietyChildFactory extends ChildFactory<Variety> implements PropertyChangeListener {

    private CropDefinition cropDefinition;
    private Lookup lookup;

    public VarietyChildFactory(CropDefinition cropDefinition, Lookup lookup) {
        this.lookup = lookup;
        this.cropDefinition = cropDefinition;
        cropDefinition.addPropertyChangeListener(CropDefinition.PROP_VARIETIES, this);
    }

    @Override
    protected boolean createKeys(List<Variety> toPopulate) {
        toPopulate.addAll(this.cropDefinition.getVarieties());
        return true;
    }

    @Override
    protected Node createNodeForKey(Variety variety) {
        try {
            return new VarietyNode(variety, lookup);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        this.refresh(true);
    }
}
